@@ -1,6 +1,6 @@
 use utf8;
 package Mojolicious::Plugin::DevexpressHelpers::Helpers;
-$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.152460';
+$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.153350';
 #ABSTRACT: Helpers for Devexpress controls are defined here
 use Modern::Perl;
 use Mojo::ByteStream;
@@ -12,6 +12,45 @@ use constant DEBUG => 0;
 our $OUT_DECODE = 'UTF-8';
 our $INDENT_BINDING = 0;
 
+my @generic_controls = qw(
+		Accordion
+		Autocomplete
+		Box
+		CheckBox
+		Calendar
+		ColorBox
+		ContextMenu
+		DateBox
+		FileUploader
+		Gallery
+		List
+		LoadIndicator
+		Lookup
+		Map
+		MultiView
+		NavBar
+		NumberBox
+		PivotGrid
+		PivotGridFieldChooser
+		Popover
+		ProgressBar
+		RadioGroup
+		RangeSlider
+		Resizable
+		ResponsiveBox
+		Scheduler
+		ScrollView
+		SelectBox
+		Slider
+		Switch
+		TabPanel
+		Tabs
+		TagBox
+		TextAread
+		TextBox
+		TitleView
+	);
+
 
 sub out{
 	my $tag = shift;
@@ -170,99 +209,38 @@ sub dxpopup{
 }
 
 
-sub dxswitch{
-	my $c = shift;
-	my $attrs = parse_attributs( $c, [qw(id value label)], @_ );
-	my $id = delete($attrs->{id});
-	if (my $name = $id) {
-		$attrs->{attr}{name}=$name;
-	}
-	$id //= new_id( $c, $attrs );
-	$attrs->{onText}  //= 'On';
-	$attrs->{offText} //= 'Off';
-	my (@before, @after);
-	if(my $label = delete($attrs->{label})){
-		push @before, '<div class="dx-field">';
-		push @before, '<div class="dx-field-label">'.$label.'</div>';
-		push @before, '<div class="dx-field-value">';
-		push @after, '</div>';
-		push @after, '</div>';
-	}
+
+sub mk_dxcontrol{
+	my $dxControl = shift;
+	my $generic = sub{
+		my $c = shift;
+		my $attrs = parse_attributs( $c, [qw(id value label)], @_ );
+		my $id = delete($attrs->{id});
+		if (my $name = $id) {
+			$attrs->{attr}{name}=$name;
+		}
+		
+		$id //= new_id( $c, $attrs );
 	
-	dxbind( $c, 'dxSwitch' => $id => $attrs, undef, \@before, \@after );	
+		my (@before, @after);
+		if(my $label = delete($attrs->{label})){
+			push @before, '<div class="dx-field">';
+			push @before, '<div class="dx-field-label">'.$label.'</div>';
+			push @before, '<div class="dx-field-value">';
+			push @after, '</div>';
+			push @after, '</div>';
+		}
+		
+		dxbind( $c, $dxControl => $id => $attrs, undef, \@before, \@after );	
+	};
+	
+	{
+		no strict 'refs';
+		*{__PACKAGE__.'::'.lc $dxControl} = $generic;
+	}
 }
 
 
-sub dxtextbox{
-	my $c = shift;
-	my $attrs = parse_attributs( $c, [qw(id value label)], @_ );
-	my $id = delete($attrs->{id});
-	if (my $name = $id) {
-		$attrs->{attr}{name}=$name;
-	}
-	
-	$id //= new_id( $c, $attrs );
-
-	my (@before, @after);
-	if(my $label = delete($attrs->{label})){
-		push @before, '<div class="dx-field">';
-		push @before, '<div class="dx-field-label">'.$label.'</div>';
-		push @before, '<div class="dx-field-value">';
-		push @after, '</div>';
-		push @after, '</div>';
-	}
-	
-	dxbind( $c, 'dxTextBox' => $id => $attrs, undef, \@before, \@after );	
-}
-
-
-sub dxlookup{
-	my $c = shift;
-	my $attrs = parse_attributs( $c, [qw(id value label)], @_ );
-	my $id = delete($attrs->{id});
-	if (my $name = $id) {
-		$attrs->{attr}{name}=$name;
-	}
-	
-	$id //= new_id( $c, $attrs );
-
-	my (@before, @after);
-	if(my $label = delete($attrs->{label})){
-		push @before, '<div class="dx-field">';
-		push @before, '<div class="dx-field-label">'.$label.'</div>';
-		push @before, '<div class="dx-field-value">';
-		push @after, '</div>';
-		push @after, '</div>';
-	}
-	
-	dxbind( $c, 'dxLookup' => $id => $attrs, undef, \@before, \@after );	
-}
-
-sub dxselectbox{
-	my $c = shift;
-	my $attrs = parse_attributs( $c, [qw(id value label)], @_ );
-	my $id = delete($attrs->{id});
-	if (my $name = $id) {
-		$attrs->{attr}{name}=$name;
-	}
-	
-	$id //= new_id( $c, $attrs );
-
-	my (@before, @after);
-	if(my $label = delete($attrs->{label})){
-		push @before, '<div class="dx-field">';
-		push @before, '<div class="dx-field-label">'.$label.'</div>';
-		push @before, '<div class="dx-field-value">';
-		push @after, '</div>';
-		push @after, '</div>';
-	}
-	
-	dxbind( $c, 'dxSelectBox' => $id => $attrs, undef, \@before, \@after );	
-}
-
-
-
-
 sub dxbuild {
 	my $c = shift;
 	my $dxhelper = $c->stash('dxHelper') or return;
@@ -300,13 +278,15 @@ sub required_assets{
 my @without_prefix = qw( dxbuild required_assets require_asset indent_binding );
 
 #Helper method to export with prepending a prefix
-my @with_prefix = qw( Button DataGrid Popup TextBox TextArea Switch
-	Menu LoadPanel
-	SelectBox NumberBox List DateBox CheckBox Calendar Box Lookup );
+my @with_prefix = (qw( Button DataGrid Popup Menu LoadPanel Lookup ),
+				   @generic_controls);
 sub register {
 	my ( $self, $app, $args ) = @_;
 	my $tp = $args->{tag_prefix};
 	
+	#build generic dx-controls
+	mk_dxcontrol( "dx$_" ) for @generic_controls;
+	
 	SUB_NO_PREFIX:
 	for my $subname ( @without_prefix ){
 		my $lc_name = lc $subname;
@@ -348,7 +328,7 @@ Mojolicious::Plugin::DevexpressHelpers::Helpers - Helpers for Devexpress control
 
 =head1 VERSION
 
-version 0.152460
+version 0.153350
 
 =head1 SUBROUTINES/METHODS
 
@@ -443,30 +423,24 @@ B<Note: It will ignore all other options specified in the hash reference.>
 			contentElement.append('<p>Hello!</p>');
 		}};
 
-=head2 dxswitch C<[ $id [, $value [, $label] ] ], [\%opts]>
+=head2 mk_dxcontrol C<$dxControlName>
 
+In this package:
+
+	mk_dxcontrol('dxNumberBox');
+	mk_dxcontrol('dxSwitch');
+	mk_dxcontrol('dxTextBox');
+	mk_dxcontrol('dxLookup');
+	mk_dxcontrol('dxSelectBox');
+
+In your template:
+
+	%= dxnumberbox 'age' => $value => 'Age: ', { placeHolder => 'Enter your age' }
 	%= dxswitch 'mySwitch' => $boolean_value => 'Enabled: '
-
-=head2 dxtextbox C<[ $id, [ $value, [ $label, ] ] ], [\%opts]>
-
 	%= dxtextbox 'name' => $value => 'Name: ', { placeHolder => 'Type a name' }
-
-=head2 dxlookup C<[ $id, [ $value, [ $label, ] ] ], [\%opts]>
-
 	%= dxlookup 'name' => $value => 'Name: ', { dataSource => $ds, valueExpr=> $ve, displayExpr => $de }
-
-=head2 dxselectbox C<[ $id, [ $value, [ $label, ] ] ], [\%opts]>
-
 	%= dxselectbox 'name' => $value => 'Name: ', { dataSource => $ds, valueExpr=> $ve, displayExpr => $de }
 
-=for comment TextArea
-NumberBox
-List
-DateBox
-CheckBox
-Calendar
-Box
-
 =head2 dxbuild
 
 Build the binding between jQuery and divs generated by plugin helpers such as dxbutton.
